#
# spec file for package clair
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define cli_executable_name clairctl
%define services clair.service clair-indexer.service clair-matcher.service clair-watcher.service

Name:           clair
Version:        4.8.0
Release:        1.1
Summary:        Vulnerability Static Analysis for Containers
License:        Apache-2.0
URL:            https://github.com/quay/clair
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        clair.service
Source3:        clair-indexer.service
Source4:        clair-matcher.service
Source5:        clair-watcher.service
BuildRequires:  go >= 1.23

%description
Clair is an open source project for the static analysis of vulnerabilities in
application containers (currently including OCI and docker).

Clients use the Clair API to index their container images and can then match it
against known vulnerabilities.

Our goal is to enable a more transparent view of the security of
container-based infrastructure. Thus, the project was named Clair after the
French term which translates to clear, bright, transparent.

%package -n %{cli_executable_name}
Summary:        CLI for the Clair Vulnerability scanner

%description -n %{cli_executable_name}
clairctl is a command line tool for working with Clair. This CLI is capable of
generating manifests from most public registries (dockerhub, quay.io, Red Hat
Container Catalog) and submitting them for analysis to a running Clair.

%prep
%autosetup -p 1 -a 1
chmod -x LICENSE

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -buildvcs=false \
   -ldflags="-X github.com/quay/clair/v4/cmd.Version=%{version}" \
   -o bin/ ./cmd/...

%install
# Install the clair binary
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# Install the clairctl binary
install -D -m 0755 bin/%{cli_executable_name} %{buildroot}/%{_bindir}/%{cli_executable_name}

# Systemd unit files
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/clair.service
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/clair-indexer.service
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_unitdir}/clair-matcher.service
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_unitdir}/clair-watcher.service

# configuration directory
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/

%check
%{buildroot}/%{_bindir}/%{cli_executable_name} --version|grep -q %{version}

%pre
%service_add_pre %{services}

%post
%service_add_post %{services}

%preun
%service_del_preun %{services}

%postun
%service_del_postun %{services}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/clair.service
%{_unitdir}/clair-indexer.service
%{_unitdir}/clair-matcher.service
%{_unitdir}/clair-watcher.service
%dir %{_sysconfdir}/%{name}/

%files -n %{cli_executable_name}
%doc README.md
%license LICENSE
%{_bindir}/%{cli_executable_name}

%changelog
* Sat Dec  7 2024 andrea.manzini@suse.com
- Update to version 4.8.0:
  * bump deps
  * stomp: guard against race in test
  * openshift: add backstop cron manifest
  * openshift: handle multiple Dockerfiles in build script
  * quaybackstop: add backstop GC command
  * introspection: lints
  * contrib: correct position of startupProbe spec
  * contrib/openshfit: only start buildkitd container if needed
  * contrib/openshift: login shenanigans
  * contrib/openshift: avoid patching when using upstream images
  * clair: add platform-specific signals
  * introspection: allow trace shutdown hook full timeout
  * clair: break cancellation chain for request contexts
  * clair: redo shutdown structure
  * docs: add building and Makefile usage sections
  * chore: run the go formatting over the repo
  * contrib: update `build_and_deploy.sh` script
  * openshift: have the pr_check script "dry run" a build
  * openshift: add "dry run" flag
  * auto: improve log messages
  * chore: fix some comments
  * chore: use the merge-multiple directive when downloading binaries
  * chore: Add merge step when creating release binaries
  * contrib: account for different container engine clients
  * contrib: update build script to use podman
  * httptransport: fix test flake
  * contrib: remove rms that were needed for previous fetcher
  * chore: update production manifest with new tmp dir
  * docs: add mention of disk space path and usage
  * initialize: use defaults for NewRemoteFetcher
  * httptransport: GET vuln report returns 404 when indexing in-progress
  * documentation: correct stale configuration options
  * httptransport: change api error handling to panic internally
  * httptransport: add metrics test
  * httputil: add test for non-OK statuses
  * httptransport: add unauthenticated "/robots.txt" endpoint
  * httptransport: add "robots.txt" endpoint
  * cmd: add exported source date
  * config: update minimum TLS version for server
  * docs: add OTLP configuration to prose documentation
  * chore: Add Go 1.22 support via moved godeltaprof dependancy bump
  * contrib: update dashboard regex
  * cmd: annotate fake key for gitleaks
  * chore: clean up sample config
  * openshift: make build_and_deploy script shellcheck-clean
  * config: Update comment to describe currently supported updaters
  * admin: add a check for compatible migration version
  * admin: add command to update go packages with norm_version
  * all: fix incorrect API paths
  * all: fix some typos
  * amqp: migrate to maintained package
  * chore: migrate go-jose to maintained version
  * config: add Sentry config
  * contrib: simplify openshift/pr_check.sh
  * config: add OTLP configuration types
  * httptransport: add client-close detection
  * httptransport: use compression middleware
  * httptransport: lints
  * httptransport: rework constructor
  * httptransport: update DiscoveryHandler to new style
  * httptransport: re-instrument handlers with new primitives
  * httptransport: exit goroutine in error helper
  * webhook: move+update debug server
  * httputil: add response recorder
  * compress: update compression middleware
  * admin: add pre v4.7.3 admin command to create index
  * contrib: add grafana dashboards for deletion metrics
  * Documentation: add more information on how to test and get started
  * config: fix typo
* Fri May 31 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.7.4:
  * chore: 4.7.4 changelog bump
  * chore: Add merge step when creating release binaries
  * chore: update go version for release
  * chore: update claircore to v1.5.27
  * chore: update go version
  * Dockerfile: remove sh loop
  * cicd: add container version skew check
  * cicd: update testing workflow
  * cicd: don't upload workspace on failure
  * cicd: change version specifiers to be major-version only
* Fri May 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package clair: Vulnerability Static Analysis for Containers,
  including the clairctl CLI
